@@ -1,15 +1,23 @@
 #*****************************************
 #
-# (C) Copyright IBM Corp. 2017
+# (C) Copyright IBM Corp. 2017, 2020
 # Author: Ernesto Arandia & Bradley J Eck
 #
 #*****************************************
 
 context("get coord")
 test_that("no crash calling on closed toolkit",{
-  expect_false( getOpenflag() )
   expect_error( x <- ENgetcoord(1) ) 
 })
+test_that("works for single input",{
+
+  ENopen("Net1.inp","Net1.rpt") 
+  xy <- ENgetcoord(1) 
+  ENclose() 
+  expect_equal(xy, c(x=20.0, y=70.0)) 
+  
+
+}) 
 test_that("works for single input",{
   ENopen("Net3.inp","Net3.rpt")
   ix <- ENgetnodeindex("15")
@@ -32,7 +40,6 @@ test_that("get error 203 on no index",{
 
 context("set coord")
 test_that("no crash calling on closed toolkit",{
-  expect_false( getOpenflag() )
   expect_error( x <- ENsetcoord(1) ) 
 })
 test_that("works for single input",{
